OC.L10N.register(
    "files",
    {
    "Rename" : "Nimeä uudelleen",
    "Delete" : "Poista",
    "Error" : "Virhe",
    "Favorite" : "Suosikit",
    "Save" : "Tallenna",
    "Settings" : "Asetukset",
    "New folder" : "Luo kansio",
    "Folder" : "Kansio",
    "Upload" : "Lähetä"
},
"nplurals=2; plural=(n != 1);");
